@@ -8,12 +8,12 @@
 #' @template right
 #'
 #' @examples
-#' posixct_() |> show_example()
+#' posixct_() %>% show_example()
 #' posixct_bounded(
 #'   left = as.POSIXct("2020-01-01 00:00:00"),
 #'   right = as.POSIXct("2021-01-01 00:00:00")
-#' ) |> show_example()
-#' posixct_(len = 10L, any_na = TRUE) |> show_example()
+#' ) %>% show_example()
+#' posixct_(len = 10L, any_na = TRUE) %>% show_example()
 #' @template generator
 #' @export
 posixct_ <- function(len = c(1L, 10L), any_na = FALSE) {
@@ -26,10 +26,10 @@ posixct_bounded <- function(left, right, len = c(1L, 10L), any_na = FALSE) {
   as_posixct <-
     purrr::partial(as.POSIXct, origin = "1970-01-01")
 
-  qc_gen(\(len2 = len)
-    hedgehog::gen.unif(as.double(left), as.double(right)) |>
-      replace_some_with(NA_real_, any_na) |>
-      hedgehog::gen.with(as_posixct) |>
+  qc_gen(function(len2 = len)
+    hedgehog::gen.unif(as.double(left), as.double(right)) %>%
+      replace_some_with(NA_real_, any_na) %>%
+      hedgehog::gen.with(as_posixct) %>%
       vectorize(len2)
   )
 }
